@@ -95,10 +95,10 @@ class PagamentoBanco(models.Model):
         unique_together = (('banco', 'conta'),)
 
     def __unicode__(self):
-        return unicode(self.nome)
+        return unicode(self.banco.nome)
 
     def __repr__(self):
-        return slugify(self.nome)
+        return slugify(self.banco.nome)
 
     def save(self, *args, **kwargs):
         if self.conta and not self.contrato_id:
@@ -115,6 +115,7 @@ class FormaPagamentoConfiguracao(models.Model):
     usuario = models.CharField(db_column="pagamento_configuracao_usuario", max_length=128, null=True)
     senha = models.CharField(db_column="pagamento_configuracao_senha", max_length=128, null=True)
     token = models.CharField(db_column="pagamento_configuracao_token", max_length=128, null=True)
+    token_expiracao = models.DateTimeField(db_column="pagamento_configuracao_token_expiracao", null=True)
     assinatura = models.CharField(db_column="pagamento_configuracao_assinatura", max_length=128, null=True)
     codigo_autorizacao = models.CharField(db_column="pagamento_configuracao_codigo_autorizacao", max_length=128, null=True)
     aplicacao = models.CharField(db_column="pagamento_configuracao_aplicacao_id", max_length=128, null=True, default=None)
