@@ -8,14 +8,14 @@ class DadosCobranca(models.Model):
 
     id = models.AutoField(db_column="dados_cobranca_id", primary_key=True)
     forma_pagamento = models.CharField(db_column="dados_cobranca_forma_pagamento")
-    tipo = models.CharField(db_column="dados_cobranca_tipo")
+    tipo_pessoa = models.CharField(db_column="dados_cobranca_tipo_pessoa")
     email_nfe = models.CharField(db_column="dados_cobranca_email_nfe")
     nome_responsavel = models.CharField(db_column="dados_cobranca_nome_responsavel")
     cpf = models.CharField(db_column="dados_cobranca_cpf")
     razao_social = models.CharField(db_column="dados_cobranca_razao_social")
     cnpj = models.CharField(db_column="dados_cobranca_cnpj")
-    telefone_fixo = models.CharField(db_column="dados_cobranca_telefone_fixo")
-    telefone_celular = models.CharField(db_column="dados_cobranca_telefone_celular")
+    telefone_principal = models.CharField(db_column="dados_cobranca_telefone_principal")
+    telefone_alternativo = models.CharField(db_column="dados_cobranca_telefone_alternativo")
     endereco_logradouro = models.CharField(db_column="dados_cobranca_endereco_logradouro")
     endereco_numero = models.CharField(db_column="dados_cobranca_endereco_numero")
     endereco_complemento = models.CharField(db_column="dados_cobranca_endereco_complemento")
@@ -39,8 +39,7 @@ class DadosCobrancaCartao(models.Model):
     """
 
     id = models.AutoField(db_column="dados_cobranca_cartao_id", primary_key=True)
-    bandeira = models.CharField(db_column="dados_cobranca_cartao_bandeira",)
-    nome = models.CharField(db_column="dados_cobranca_cartao_nome",)
+    nome_portador = models.CharField(db_column="dados_cobranca_cartao_nome_portador",)
     numero = models.CharField(db_column="dados_cobranca_cartao_numero", max_length=64, null=False)
     cvv = models.CharField(db_column="dados_cobranca_cartao_cvv", max_length=64, null=False)
     expiracao_mes = models.CharField(db_column="dados_cobranca_cartao_expiracao_mes", max_length=255, null=False)
@@ -51,7 +50,7 @@ class DadosCobrancaCartao(models.Model):
 
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
     contrato = models.ForeignKey("plataforma.Contrato", db_column="contrato_id")
-    dados_cobranca = models.ForeignKey("faturamento.DadosCobranca", db_column="dados_cobranca_id")
+    dados_cobranca = models.ForeignKey("DadosCobranca", db_column="dados_cobranca_id")
 
     class Meta:
         db_table = u"faturamento\".\"tb_dados_cobranca_cartao"
@@ -69,14 +68,14 @@ class Fatura(models.Model):
     valor_desconto = models.DecimalField(db_column="fatura_valor_desconto", decimal_places=2, max_digits=12)
     valor_subtotal = models.DecimalField(db_column="fatura_valor_subtotal", decimal_places=2, max_digits=12)
     dados_forma_pagamento = models.CharField(db_column="fatura_dados_forma_pagamento")
-    dados_tipo = models.CharField(db_column="fatura_dados_tipo")
+    dados_tipo_pessoa = models.CharField(db_column="fatura_dados_tipo_pessoa")
     dados_email_nfe = models.CharField(db_column="fatura_dados_email_nfe")
     dados_nome_responsavel = models.CharField(db_column="fatura_dados_nome_responsavel")
     dados_cpf = models.CharField(db_column="fatura_dados_cpf", default=None)
     dados_razao_social = models.CharField(db_column="fatura_dados_razao_social", default=None)
     dados_cnpj = models.CharField(db_column="fatura_dados_cnpj", default=None)
-    dados_telefone_fixo = models.CharField(db_column="fatura_dados_telefone_fixo", default=None)
-    dados_telefone_celular = models.CharField(db_column="fatura_dados_telefone_celular", default=None)
+    dados_telefone_principal = models.CharField(db_column="fatura_dados_telefone_principal", default=None)
+    dados_telefone_alternativo = models.CharField(db_column="fatura_dados_telefone_alternativo", default=None)
     dados_endereco_logradouro = models.CharField(db_column="fatura_dados_endereco_logradouro")
     dados_endereco_numero = models.CharField(db_column="fatura_dados_endereco_numero")
     dados_endereco_complemento = models.CharField(db_column="fatura_dados_endereco_complemento", default=None)
@@ -111,7 +110,7 @@ class FaturaItem(models.Model):
 
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
     contrato = models.ForeignKey("plataforma.Contrato", db_column="contrato_id")
-    fatura = models.ForeignKey("faturamento.Fatura", db_column="fatura_id")
+    fatura = models.ForeignKey("Fatura", db_column="fatura_id")
 
     class Meta:
         db_table = u"faturamento\".\"tb_fatura_item"
@@ -141,16 +140,17 @@ class Plano(models.Model):
     data_criacao = models.DateTimeField(db_column="plano_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="plano_data_modificacao", auto_now=True)
 
-    colecao = models.ForeignKey("faturamento.Colecao", db_column="colecao_id")
+    colecao = models.ForeignKey("Colecao", db_column="colecao_id")
 
     class Meta:
+        app_label = 'faturamento'
         db_table = u"faturamento\".\"tb_plano"
 
 
 class PlanoAssinatura(models.Model):
 
     id = models.AutoField(db_column="plano_assinatura_id", primary_key=True)
-    anterior_id = models.IntegerField(db_column="plano_assinatura_anterior_id", default=None)
+    acao = models.TextField(db_column="plano_assinatura_acao", default='MANTEVE')
     ciclo_inicio = models.DateField(db_column="plano_assinatura_ciclo_inicio")
     ciclo_fim = models.DateField(db_column="plano_assinatura_ciclo_fim")
     controle_trafego = models.IntegerField(db_column="plano_assinatura_controle_trafego", default=0)
@@ -161,8 +161,8 @@ class PlanoAssinatura(models.Model):
 
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
     contrato = models.ForeignKey("plataforma.Contrato", db_column="contrato_id")
-    plano = models.ForeignKey("faturamento.Plano", db_column="plano_id")
-    fatura = models.ForeignKey("faturamento.Fatura", db_column="fatura_id")
+    plano = models.ForeignKey("Plano", db_column="plano_id")
+    fatura = models.ForeignKey("Fatura", db_column="fatura_id")
 
     class Meta:
         db_table = u"faturamento\".\"tb_plano_assinatura"
