@@ -299,6 +299,16 @@ class PedidoVenda(models.Model):
         """Retorna o maior prazo de envio de todos os itens do pedido."""
         return self.itens.aggregate(prazo=Max('disponibilidade')).get('prazo')
 
+    @property
+    def pagamento(self):
+        """Retorna a primeira relação de FormaPagamento do pedido."""
+        if not hasattr(self, '_pagamento'):
+            try:
+                self._pagamento = self.pagamentos.all()[0]
+            except IndexError:
+                self._pagamento = None
+        return self._pagamento
+
 
 class PedidoVendaItem(models.Model):
     """Itens de um pedido de venda.
